# API Reference

:::{important}
This list is **INCOMPLETE**! If you think something is missing, try searching for it first. If you still
can't find it, please open an issue on the [LibRapid GitHub repository](https://github.com/LibRapid/LibRapid/issues).
:::

::::{grid} 1 2 2 3
:margin: 4 4 0 0
:gutter: 1

:::{grid-item-card} {octicon}`table` Arrays, Matrices and Linear Algebra
:link: array/array
:link-type: doc

Multidimensional arrays, matrices, linear algebra and more.
:::

:::{grid-item-card} {octicon}`server` Machine Learning
:link: ml/ml
:link-type: doc

Machine learning in LibRapid.
:::

:::{grid-item-card} {octicon}`columns` Vectors
:link: vector/vector
:link-type: doc

Fixed-size vectors and supported operations.
:::

:::{grid-item-card} {octicon}`list-unordered` Complex Numbers
:link: complex/complex
:link-type: doc

Complex numbers and their operations.
:::

:::{grid-item-card} {octicon}`stack` Sets
:link: set/set
:link-type: doc

Mathematical sets.
:::

:::{grid-item-card} {octicon}`number` Mathematics
:link: math/math
:link-type: doc

General mathematical operations that work on most data types.
:::

:::{grid-item-card} {octicon}`x` Multi-Precision Arithmetic
:link: multiPrecision/multiPrecision
:link-type: doc

Arbitrary-precision integers, floating points and rationals.
:::

:::{grid-item-card} {octicon}`tools` Utilities
:link: utility/utility
:link-type: doc

Utility functions and classes to support development.
:::
::::

```{toctree}
:hidden:
:maxdepth: 3

Usage Examples <topics/topics>
Arrays, Matrices and Linear Algebra <array/array>
Vectors <vector/vector>
Complex Numbers <complex/complex>
Sets <set/set>
Mathematics <math/math>
Multi-Precision Arithmetic <multiPrecision/multiPrecision>
Utilities <utility/utility>
```
